@@ -9,12 +9,11 @@ logger = logging.getLogger(__name__)
 # https://daskhub.dev.ctaodc.ch/services/downloadservice/fetch/pnfs/cta.cscs.ch/lst/DL1/20230226/v0.9_calib12100/tailcut84
 
 hubbase = "http://hub:5000"
-dsbase = urljoin(hubbase, "services/downloadservice/fetch/")
+dsbase = urljoin(hubbase, "services/downloadservice/fetch/pnfs/cta.cscs.ch")
 
 
 def list_dir(url):
     fullurl = urljoin(urljoin(dsbase, "pnfs/cta.cscs.ch/"), url)
-    print(fullurl)
     
     r = requests.get(
                 fullurl,
@@ -35,7 +34,7 @@ def fetch_and_save_file(url, fn=None):
 
     with open(fn, "wb") as outf:
         with requests.get(
-            urljoin(dsbase, "pnfs/cta.cscs.ch", url),
+            urljoin(dsbase, url),
             params = {'token': os.getenv("JUPYTERHUB_API_TOKEN")},
             stream=True
         ) as f:          
